@@ -4,7 +4,8 @@
 General utilities for the application.
 """
 from __future__ import unicode_literals
-default_app_config = 'calaccess_processed.apps.CalAccessProcessedConfig'
+
+default_app_config = "calaccess_processed.apps.CalAccessProcessedConfig"
 
 
 def archive_directory_path(instance, filename):
@@ -15,17 +16,17 @@ def archive_directory_path(instance, filename):
 
     if isinstance(instance, ProcessedDataZip):
         release_datetime = instance.version.raw_version.release_datetime
-        f_name, f_ext = filename.split('.')
-        return '{fn}_{dt:%Y-%m-%d_%H-%M-%S}.{fx}'.format(
+        f_name, f_ext = filename.split(".")
+        return "{fn}_{dt:%Y-%m-%d_%H-%M-%S}.{fx}".format(
             fn=f_name,
             dt=release_datetime,
             fx=f_ext,
         )
     elif isinstance(instance, ProcessedDataFile):
         release_datetime = instance.version.raw_version.release_datetime
-        return '{dt:%Y-%m-%d_%H-%M-%S}/{f}'.format(dt=release_datetime, f=filename)
+        return "{dt:%Y-%m-%d_%H-%M-%S}/{f}".format(dt=release_datetime, f=filename)
     else:
         raise TypeError("Must be ProcessedDataVersion or ProcessedDataFile instance.")
 
 
-__all__ = ('archive_directory_path',)
+__all__ = ("archive_directory_path",)
