@@ -6,6 +6,4 @@ Utilities for correcting raw data.
 from .candidate_party import candidate_party
 
 
-__all__ = (
-    'candidate_party',
-)
+__all__ = ("candidate_party",)
