@@ -3,18 +3,9 @@
 """
 Import all of the managers from submodules and thread them together.
 """
-from .candidacies import (
-    OCDCandidacyQuerySet,
-    OCDCandidacyManager
-)
-from .candidatecontests import (
-    OCDCandidateContestQuerySet,
-    OCDCandidateContestManager
-)
-from .elections import (
-    OCDPartisanPrimaryManager,
-    OCDElectionManager
-)
+from .candidacies import OCDCandidacyQuerySet, OCDCandidacyManager
+from .candidatecontests import OCDCandidateContestQuerySet, OCDCandidateContestManager
+from .elections import OCDPartisanPrimaryManager, OCDElectionManager
 from .parties import OCDPartyManager
 
 
@@ -25,5 +16,5 @@ __all__ = (
     "OCDCandidateContestManager",
     "OCDPartisanPrimaryManager",
     "OCDElectionManager",
-    "OCDPartyManager"
+    "OCDPartyManager",
 )
