@@ -1,10 +1,6 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-"""
-Basic configuration for the application.
-"""
-from __future__ import unicode_literals
+"""Basic configuration for the application."""
 import os
+
 from django.apps import AppConfig
 
 
@@ -12,12 +8,13 @@ class CalAccessProcessedFilingsConfig(AppConfig):
     """
     Application configuration.
     """
-    name = 'calaccess_processed_filings'
+
+    name = "calaccess_processed_filings"
     verbose_name = "CAL-ACCESS processed data: Filings"
-    default_auto_field = 'django.db.models.AutoField'
+    default_auto_field = "django.db.models.AutoField"
 
     # Where SQL files are stored in this application
-    sql_directory_path = os.path.join(os.path.dirname(__file__), 'sql')
+    sql_directory_path = os.path.join(os.path.dirname(__file__), "sql")
 
     def get_filing_model_lookup(self):
         """
@@ -39,7 +36,7 @@ class CalAccessProcessedFilingsConfig(AppConfig):
         model_list = [m for m in model_list if not m._meta.proxy]
 
         # Filter down to just models with "filing" in the name
-        model_list = [m for m in model_list if 'filings' in str(m)]
+        model_list = [m for m in model_list if "filings" in str(m)]
 
         # Return what's left
         return model_list
