@@ -1,11 +1,9 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-"""
-Filing-related models, managers and mixins.
-"""
-import requests
+"""Filing-related models, managers and mixins."""
 from time import sleep
-from calaccess_processed.models.base import CalAccessBaseModel
+
+import requests
+
+from calaccess_processed.models import CalAccessBaseModel
 from calaccess_processed_filings.managers import FilingsManager
 
 
@@ -13,14 +11,16 @@ class FilingBaseModel(CalAccessBaseModel):
     """
     Base model for all the filings models.
     """
+
     objects = FilingsManager()
 
     class Meta:
         """
         Meta model options.
         """
+
         abstract = True
-        app_label = 'calaccess_processed_filings'
+        app_label = "calaccess_processed_filings"
 
     @property
     def pdf_url(self):
@@ -29,10 +29,12 @@ class FilingBaseModel(CalAccessBaseModel):
         """
         # If it's a Filing, it will have an amendment count. If it's a Version it will have an amend_id.
         try:
-            amendid = getattr(self, 'amendment_count')
+            amendid = getattr(self, "amendment_count")
         except AttributeError:
-            amendid = getattr(self, 'amend_id')
-        return 'http://cal-access.sos.ca.gov/PDFGen/pdfgen.prg?filingid={}&amendid={}'.format(self.filing_id, amendid)
+            amendid = getattr(self, "amend_id")
+        return "http://cal-access.sos.ca.gov/PDFGen/pdfgen.prg?filingid={}&amendid={}".format(
+            self.filing_id, amendid
+        )
 
     @property
     def has_pdf(self):
