@@ -25,29 +25,33 @@ class Form497Filing(CampaignFinanceFilingBase):
     each filing. All versions of Schedule 497 filings can be found in
     schedule497version.
     """
+
     filing_id = models.IntegerField(
-        verbose_name='filing id',
+        verbose_name="filing id",
         primary_key=True,
         null=False,
-        help_text='Unique identification number for the Schedule 497 filing ('
-                  'from CVR_CAMPAIGN_DISCLOSURE_CD.FILING_ID)',
+        help_text="Unique identification number for the Schedule 497 filing ("
+        "from CVR_CAMPAIGN_DISCLOSURE_CD.FILING_ID)",
     )
     amendment_count = models.IntegerField(
-        verbose_name='Count amendments',
+        verbose_name="Count amendments",
         null=False,
-        help_text='Number of amendments to the Schedule 497 filing (from '
-                  'maximum value of CVR_CAMPAIGN_DISCLOSURE_CD.AMEND_ID)',
+        help_text="Number of amendments to the Schedule 497 filing (from "
+        "maximum value of CVR_CAMPAIGN_DISCLOSURE_CD.AMEND_ID)",
     )
 
     class Meta:
         """
         Model options.
         """
-        app_label = 'calaccess_processed_filings'
-        index_together = ((
-            'filing_id',
-            'amendment_count',
-        ),)
+
+        app_label = "calaccess_processed_filings"
+        index_together = (
+            (
+                "filing_id",
+                "amendment_count",
+            ),
+        )
         verbose_name = "Form 497 (Late Contribution) filing"
 
     def __str__(self):
@@ -62,36 +66,42 @@ class Form497FilingVersion(CampaignFinanceFilingBase):
     Schedule 497 filing. For the most recent version of each filing, see
     schedule497filing.
     """
+
     filing = models.ForeignKey(
-        'Form497Filing',
-        related_name='versions',
+        "Form497Filing",
+        related_name="versions",
         db_constraint=False,
         null=True,
         on_delete=models.SET_NULL,
-        help_text='Unique identification number for the Schedule 497 filing ('
-                  'from S497_CD.FILING_ID)',
+        help_text="Unique identification number for the Schedule 497 filing ("
+        "from S497_CD.FILING_ID)",
     )
     amend_id = models.IntegerField(
         null=False,
-        help_text='Identifies the version of the Schedule 497 filing, with 0 '
-                  'representing the initial filing (from CVR_CAMPAIGN_'
-                  'DISCLOSURE_CD.AMEND_ID)',
+        help_text="Identifies the version of the Schedule 497 filing, with 0 "
+        "representing the initial filing (from CVR_CAMPAIGN_"
+        "DISCLOSURE_CD.AMEND_ID)",
     )
 
     class Meta:
         """
         Model options.
         """
-        app_label = 'calaccess_processed_filings'
-        unique_together = ((
-            'filing',
-            'amend_id',
-        ),)
-        index_together = ((
-            'filing',
-            'amend_id',
-        ),)
+
+        app_label = "calaccess_processed_filings"
+        unique_together = (
+            (
+                "filing",
+                "amend_id",
+            ),
+        )
+        index_together = (
+            (
+                "filing",
+                "amend_id",
+            ),
+        )
         verbose_name = "Form 497 (Late Contribution) filing version"
 
     def __str__(self):
-        return '%s-%s' % (self.filing, self.amend_id)
+        return "%s-%s" % (self.filing, self.amend_id)
